PyXMake Developer Guide: PyXMake.VTL.stm_make._BaseTest Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | Static Public Attributes | List of all members
PyXMake.VTL.stm_make._BaseTest Class Reference
Inheritance diagram for PyXMake.VTL.stm_make._BaseTest:

## Public Member Functions
def | initialize_options (self)
def | finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
def | run (self)

## Public Attributes
| command
| out
| covout
| verbose

## Static Public Attributes
string | description = "Runs all unit tests using py.test."
list | user_options

## Detailed Description

    Base class for all test classes

Definition at line 933 of file stm_make.py.

## Member Data Documentation

## ◆ user_options

list PyXMake.VTL.stm_make._BaseTest.user_options
| static

Initial value:
= [
("command=", None, "Path and name of the command line tool."),
("out=", None, "Specifies the output format of the test results." \
+ "Formats: xml, standard out. Default: standard out."),
("covout=", None, "Specifies the output format of the coverage report." \
+ "Formats: xml, html.")]

Definition at line 938 of file stm_make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/VTL/stm_make.py